@@ -9,7 +9,7 @@ use constant false => 0;
 
 use DateTime::Format::Natural::Helpers qw(%flag);
 
-our $VERSION = '1.19';
+our $VERSION = '1.21';
 
 our (%init,
      %timespan,
@@ -120,6 +120,7 @@ our (%init,
 #      [ [ <index(es) of token(s) to be passed> ], ... ], --> declares which tokens will be passed to the worker method(s)
 #      [ { <additional options to be passed> }, ... ] ------> declares additional options
 #      [ <name of method to dispatch to>, ... ], -----------> declares the worker method(s)
+#      { <shared option>, ... } ----------------------------> declares shared options (post-processed)
 #    ],
 
 %grammar = (
@@ -132,6 +133,7 @@ our (%init,
          [ [] ],
          [ {} ],
          [ '_no_op' ],
+         {},
        ],
     ],
     day => [
@@ -147,6 +149,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(yesterday)$/i },
@@ -159,6 +162,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(tomorrow)$/i },
@@ -171,6 +175,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
     ],
     dayframe => [
@@ -186,6 +191,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(afternoon)$/i },
@@ -198,6 +204,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(evening)$/i },
@@ -210,6 +217,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_variant' ],
+         {},
        ]
     ],
     daytime_noon_midnight => [
@@ -225,6 +233,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime' ],
+         {},
        ],
        [
          { 0 => qr/^(midnight)$/i },
@@ -237,6 +246,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime' ],
+         {},
        ],
     ],
     daytime_noon_midnight_at => [
@@ -255,6 +265,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hour => 12 } ],
          [ '_unit_variant', '_daytime' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => 'at', 2 => qr/^(midnight)$/i },
@@ -270,6 +281,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hour => 0 } ],
          [ '_unit_variant', '_daytime' ],
+         {},
        ],
        [
          { 0 => qr/^(today)$/i, 1 => 'at', 2 => qr/^(noon)$/i },
@@ -285,6 +297,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hour => 12 } ],
          [ '_unit_variant', '_daytime' ],
+         {},
        ],
        [
          { 0 => qr/^(today)$/i, 1 => 'at', 2 => qr/^(midnight)$/i },
@@ -300,6 +313,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hour => 0 } ],
          [ '_unit_variant', '_daytime' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => 'at', 2 => qr/^(noon)$/i },
@@ -315,6 +329,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hour => 12 } ],
          [ '_unit_variant', '_daytime' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => 'at', 2 => qr/^(midnight)$/i },
@@ -330,6 +345,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hour => 0 } ],
          [ '_unit_variant', '_daytime' ],
+         {},
        ],
     ],
     this_daytime => [
@@ -345,6 +361,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => 'this', 1 => qr/^(afternoon)$/i },
@@ -357,6 +374,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => 'this', 1 => qr/^(evening)$/i },
@@ -369,6 +387,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_variant' ],
+         {},
        ],
     ],
     dayframe_day => [
@@ -387,6 +406,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => qr/^(afternoon)$/i },
@@ -402,6 +422,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => qr/^(evening)$/i },
@@ -417,6 +438,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(today)$/i, 1 => qr/^(morning)$/i },
@@ -432,6 +454,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(today)$/i, 1 => qr/^(afternoon)$/i },
@@ -447,6 +470,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(today)$/i, 1 => qr/^(evening)$/i },
@@ -462,6 +486,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => qr/^(morning)$/i },
@@ -477,6 +502,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => qr/^(afternoon)$/i },
@@ -492,6 +518,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => qr/^(evening)$/i },
@@ -507,6 +534,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_daytime_variant' ],
+         {},
        ]
     ],
     at_daytime => [
@@ -523,6 +551,7 @@ our (%init,
          ],
          [ {}, { unit => 'day' } ],
          [ '_time', '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time_am}, 1 => qr/^(today)$/i },
@@ -536,6 +565,7 @@ our (%init,
          ],
          [ {}, { unit => 'day' } ],
          [ '_time', '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time_am}, 1 => qr/^(tomorrow)$/i },
@@ -549,6 +579,7 @@ our (%init,
          ],
          [ {}, { unit => 'day' } ],
          [ '_time', '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time_pm}, 1 => qr/^(yesterday)$/i },
@@ -562,6 +593,7 @@ our (%init,
          ],
          [ { hours => 12 }, { unit => 'day' } ],
          [ '_at', '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time_pm}, 1 => qr/^(today)$/i },
@@ -575,6 +607,7 @@ our (%init,
          ],
          [ { hours => 12 }, { unit => 'day' } ],
          [ '_at', '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time_pm}, 1 => qr/^(tomorrow)$/i },
@@ -588,6 +621,7 @@ our (%init,
          ],
          [ { hours => 12 }, { unit => 'day' } ],
          [ '_at', '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
     ],
     month => [
@@ -603,6 +637,7 @@ our (%init,
          ],
          [ { unit => 'month' } ],
          [ '_unit_date' ],
+         { truncate_to => 'month' },
        ],
     ],
     month_day => [
@@ -619,6 +654,7 @@ our (%init,
          ],
          [ {} ],
          [ '_month_day' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{month}, 1 => $RE{monthday} },
@@ -632,6 +668,7 @@ our (%init,
          ],
          [ {} ],
          [ '_month_day' ],
+         { truncate_to => 'day' },
        ]
     ],
     day_month_year_ago => [
@@ -649,6 +686,7 @@ our (%init,
         ],
         [ {}, { unit => 'year' } ],
         [ '_month_day', '_ago_variant' ],
+        { truncate_to => 'day' },
       ],
     ],
     day_month_variant_year => [
@@ -668,6 +706,7 @@ our (%init,
         ],
         [ {}, { unit => 'year' } ],
         [ '_month_day', '_unit_variant' ],
+        { truncate_to => 'day' },
       ],
       [
         { 0 => $RE{monthday}, 1 => $RE{month}, 2 => qr/^(this)$/i, 3 => 'year' },
@@ -684,6 +723,7 @@ our (%init,
         ],
         [ {}, { unit => 'year' } ],
         [ '_month_day', '_unit_variant' ],
+        { truncate_to => 'day' },
       ],
       [
         { 0 => $RE{monthday}, 1 => $RE{month}, 2 => qr/^(last)$/i, 3 => 'year' },
@@ -700,6 +740,7 @@ our (%init,
         ],
         [ {}, { unit => 'year' } ],
         [ '_month_day', '_unit_variant' ],
+        { truncate_to => 'day' },
       ],
     ],
     month_day_year => [
@@ -717,6 +758,7 @@ our (%init,
          ],
          [ {}, { unit => 'year' } ],
          [ '_month_day', '_unit_date' ],
+         { truncate_to => 'day' },
        ]
     ],
     week_variant => [
@@ -732,6 +774,7 @@ our (%init,
          ],
          [ { unit => 'week' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'week' },
@@ -744,6 +787,7 @@ our (%init,
          ],
          [ { unit => 'week' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => 'week' },
@@ -756,6 +800,7 @@ our (%init,
          ],
          [ { unit => 'week' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ]
     ],
     weekday => [
@@ -771,6 +816,7 @@ our (%init,
          ],
          [ {} ],
          [ '_weekday' ],
+         { truncate_to => 'day' },
        ],
     ],
     weekday_variant => [
@@ -787,6 +833,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => $RE{weekday} },
@@ -800,6 +847,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => $RE{weekday} },
@@ -813,6 +861,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
     ],
     year_variant => [
@@ -828,6 +877,7 @@ our (%init,
          ],
          [ { unit => 'year' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'year' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'year' },
@@ -840,6 +890,7 @@ our (%init,
          ],
          [ { unit => 'year' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'year' },
        ],
        [
          { 0 => qr/^(next)$/i, 1 => 'year' },
@@ -852,6 +903,7 @@ our (%init,
          ],
          [ { unit => 'year' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'year' }
        ],
     ],
     month_variant => [
@@ -868,6 +920,7 @@ our (%init,
          ],
          [ {} ],
          [ '_month_variant' ],
+         { truncate_to => 'month' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => $RE{month} },
@@ -881,6 +934,7 @@ our (%init,
          ],
          [ {} ],
          [ '_month_variant' ],
+         { truncate_to => 'month' },
        ],
        [
          { 0 => qr/^(next)$/i, 1 => $RE{month} },
@@ -894,6 +948,7 @@ our (%init,
          ],
          [ {} ],
          [ '_month_variant' ],
+         { truncate_to => 'month' },
        ],
     ],
     unit_literal_variant => [
@@ -909,6 +964,7 @@ our (%init,
          ],
          [ { unit => 'second' } ],
          [ '_unit_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'second' },
@@ -921,6 +977,7 @@ our (%init,
          ],
          [ { unit => 'second' } ],
          [ '_unit_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(next)$/i, 1 => 'second' },
@@ -933,6 +990,7 @@ our (%init,
          ],
          [ { unit => 'second' } ],
          [ '_unit_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(last)$/i, 1 => 'minute' },
@@ -945,6 +1003,7 @@ our (%init,
          ],
          [ { unit => 'minute' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'minute' },
@@ -957,6 +1016,7 @@ our (%init,
          ],
          [ { unit => 'minute' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(next)$/i, 1 => 'minute' },
@@ -969,6 +1029,7 @@ our (%init,
          ],
          [ { unit => 'minute' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => 'hour' },
@@ -981,6 +1042,7 @@ our (%init,
          ],
          [ { unit => 'hour' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'hour' },
@@ -993,6 +1055,7 @@ our (%init,
          ],
          [ { unit => 'hour' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => qr/^(next)$/i, 1 => 'hour' },
@@ -1005,6 +1068,7 @@ our (%init,
          ],
          [ { unit => 'hour' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => 'day' },
@@ -1017,6 +1081,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'day' },
@@ -1029,6 +1094,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(next)$/i, 1 => 'day' },
@@ -1041,6 +1107,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => 'month' },
@@ -1053,6 +1120,7 @@ our (%init,
          ],
          [ { unit => 'month' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'month' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'month' },
@@ -1065,6 +1133,7 @@ our (%init,
          ],
          [ { unit => 'month' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'month' },
        ],
        [
          { 0 => qr/^(next)$/i, 1 => 'month' },
@@ -1077,6 +1146,7 @@ our (%init,
          ],
          [ { unit => 'month' } ],
          [ '_unit_variant' ],
+         { truncate_to => 'month' },
        ],
     ],
     at => [
@@ -1088,6 +1158,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 0 } ],
          [ '_at' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time}, 1 => 'pm' },
@@ -1096,6 +1167,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 12 } ],
          [ '_at' ],
+         { truncate_to => 'minute' },
        ],
     ],
     at_combined => [
@@ -1107,6 +1179,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 0 } ],
          [ '_at' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{time_pm} },
@@ -1115,6 +1188,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 12 } ],
          [ '_at' ],
+         { truncate_to => 'minute' },
        ],
     ],
     weekday_time => [
@@ -1131,6 +1205,7 @@ our (%init,
          ],
          [ {}, {} ],
          [ '_weekday', '_time' ],
+         { truncate_to => 'minute' },
        ],
     ],
     time => [
@@ -1142,6 +1217,7 @@ our (%init,
          [ [ 0 ] ],
          [ {} ],
          [ '_time' ],
+         { truncate_to => 'minute' },
        ],
     ],
     time_full => [
@@ -1153,6 +1229,7 @@ our (%init,
          [ [ 0 ] ],
          [ {} ],
          [ '_time_full' ],
+         {},
        ],
     ],
     month_year => [
@@ -1169,6 +1246,7 @@ our (%init,
          ],
          [ { unit => 'month' }, { unit => 'year' } ],
          [ '_unit_date', '_unit_date' ],
+         { truncate_to => 'month' },
        ],
     ],
     year => [
@@ -1180,6 +1258,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'year' } ],
          [ '_unit_date' ],
+         { truncate_to => 'year' },
        ],
     ],
     count_weekday => [
@@ -1196,6 +1275,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_weekday' ],
+         { truncate_to => 'day' },
        ],
     ],
     count_yearday => [
@@ -1212,6 +1292,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_yearday_variant_year' ],
+         { truncate_to => 'day' },
        ],
     ],
     count_yearday_variant_year => [
@@ -1228,6 +1309,7 @@ our (%init,
           ],
           [ {} ],
           [ '_count_yearday_variant_year' ],
+          { truncate_to => 'day' },
         ],
         [
           { 0 => $RE{day}, 1 => 'day', 2 => qr/^(this)$/i, 3 => 'year' },
@@ -1241,6 +1323,7 @@ our (%init,
           ],
           [ {} ],
           [ '_count_yearday_variant_year' ],
+          { truncate_to => 'day' },
         ],
         [
           { 0 => $RE{day}, 1 => 'day', 2 => qr/^(last)$/i, 3 => 'year' },
@@ -1254,6 +1337,7 @@ our (%init,
           ],
           [ {} ],
           [ '_count_yearday_variant_year' ],
+          { truncate_to => 'day' },
         ],
     ],
     daytime_in_the_variant => [
@@ -1265,6 +1349,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 0 } ],
          [ '_daytime_in_the_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => 'in', 2 => 'the', 3 => 'afternoon' },
@@ -1273,6 +1358,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 12 } ],
          [ '_daytime_in_the_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => 'in', 2 => 'the', 3 => 'evening' },
@@ -1281,6 +1367,7 @@ our (%init,
          [ [ 0 ] ],
          [ { hours => 12 } ],
          [ '_daytime_in_the_variant' ],
+         {},
        ],
     ],
     ago => [
@@ -1292,6 +1379,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'second' } ],
          [ '_ago_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(minutes?)$/i, 2 => 'ago' },
@@ -1300,6 +1388,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'minute' } ],
          [ '_ago_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => 'ago' },
@@ -1308,6 +1397,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'hour' } ],
          [ '_ago_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(days?)$/i, 2 => 'ago' },
@@ -1316,6 +1406,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'day' } ],
          [ '_ago_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(weeks?)$/i, 2 => 'ago' },
@@ -1324,6 +1415,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'week' } ],
          [ '_ago_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(months?)$/i, 2 => 'ago' },
@@ -1332,6 +1424,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'month' } ],
          [ '_ago_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(years?)$/i, 2 => 'ago' },
@@ -1340,6 +1433,7 @@ our (%init,
          [ [ 0 ] ],
          [ { unit => 'year' } ],
          [ '_ago_variant' ],
+         {},
        ],
     ],
     ago_tomorrow => [
@@ -1356,6 +1450,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'second' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => $RE{number}, 2 => qr/^(minutes?)$/i, 3 => 'ago' },
@@ -1369,6 +1464,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'minute' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => $RE{number}, 2 => qr/^(hours?)$/i, 3 => 'ago' },
@@ -1382,6 +1478,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'hour' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => $RE{number}, 2 => qr/^(days?)$/i, 3 => 'ago' },
@@ -1395,6 +1492,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'day' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => $RE{number}, 2 => qr/^(weeks?)$/i, 3 => 'ago' },
@@ -1408,6 +1506,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'week' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => $RE{number}, 2 => qr/^(months?)$/i, 3 => 'ago' },
@@ -1421,6 +1520,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'month' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => $RE{number}, 2 => qr/^(years?)$/i, 3 => 'ago' },
@@ -1434,6 +1534,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'year' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
     ],
     ago_yesterday => [
@@ -1450,6 +1551,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'second' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => $RE{number}, 2 => qr/^(minutes?)$/i, 3 => 'ago' },
@@ -1463,6 +1565,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'minute' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => $RE{number}, 2 => qr/^(hours?)$/i, 3 => 'ago' },
@@ -1476,6 +1579,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'hour' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => $RE{number}, 2 => qr/^(days?)$/i, 3 => 'ago' },
@@ -1489,6 +1593,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'day' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => $RE{number}, 2 => qr/^(weeks?)$/i, 3 => 'ago' },
@@ -1502,6 +1607,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'week' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => $RE{number}, 2 => qr/^(months?)$/i, 3 => 'ago' },
@@ -1515,6 +1621,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'month' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
        [
          { 0 => qr/^(yesterday)$/i, 1 => $RE{number}, 2 => qr/^(years?)$/i, 3 => 'ago' },
@@ -1528,6 +1635,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { unit => 'year' } ],
          [ '_unit_variant', '_ago_variant' ],
+         {},
        ],
     ],
     weekday_ago_at_time => [
@@ -1545,6 +1653,7 @@ our (%init,
          ],
          [ { unit => 'month' }, {}, {} ],
          [ '_ago_variant', '_weekday', '_time' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => $RE{weekday}, 1 => $RE{number}, 2 => qr/^(months?)$/, 3 => 'ago', 4 => 'at', 5 => $RE{time_pm} },
@@ -1559,6 +1668,7 @@ our (%init,
          ],
          [ { unit => 'month' }, {}, { hours => 12 } ],
          [ '_ago_variant', '_weekday', '_at' ],
+         { truncate_to => 'minute' },
        ],
     ],
     now_variant_before => [
@@ -1575,6 +1685,7 @@ our (%init,
          ],
          [ { unit => 'second' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(minutes?)$/i, 2 => qr/^(before)$/i, 3 => 'now' },
@@ -1588,6 +1699,7 @@ our (%init,
          ],
          [ { unit => 'minute' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(before)$/i, 3 => 'now' },
@@ -1601,6 +1713,7 @@ our (%init,
          ],
          [ { unit => 'hour' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(days?)$/i,  2 => qr/^(before)$/i, 3 => 'now' },
@@ -1614,6 +1727,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(weeks?)$/i, 2 => qr/^(before)$/i, 3 => 'now' },
@@ -1627,6 +1741,7 @@ our (%init,
          ],
          [ { unit => 'week' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(months?)$/i, 2 => qr/^(before)$/i, 3 => 'now' },
@@ -1640,6 +1755,7 @@ our (%init,
          ],
          [ { unit => 'month' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(years?)$/i, 2 => qr/^(before)$/i, 3 => 'now' },
@@ -1653,6 +1769,7 @@ our (%init,
          ],
          [ { unit => 'year' } ],
          [ '_now_variant' ],
+         {},
        ],
     ],
     now_variant_from => [
@@ -1669,6 +1786,7 @@ our (%init,
          ],
          [ { unit => 'second' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(minutes?)$/i, 2 => qr/^(from)$/i, 3 => 'now' },
@@ -1682,6 +1800,7 @@ our (%init,
          ],
          [ { unit => 'minute' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(from)$/i, 3 => 'now' },
@@ -1695,6 +1814,7 @@ our (%init,
          ],
          [ { unit => 'hour' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(days?)$/i, 2 => qr/^(from)$/i, 3 => 'now' },
@@ -1708,6 +1828,7 @@ our (%init,
          ],
          [ { unit => 'day' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(weeks?)$/i, 2 => qr/^(from)$/i, 3 => 'now' },
@@ -1721,6 +1842,7 @@ our (%init,
          ],
          [ { unit => 'week' } ],
          [ '_now_variant' ],
+            {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(months?)$/i, 2 => qr/^(from)$/i, 3 => 'now' },
@@ -1734,6 +1856,7 @@ our (%init,
          ],
          [ { unit => 'month' } ],
          [ '_now_variant' ],
+         {},
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(years?)$/i, 2 => qr/^(from)$/i, 3 => 'now' },
@@ -1747,6 +1870,7 @@ our (%init,
          ],
          [ { unit => 'year' } ],
          [ '_now_variant' ],
+         {},
        ],
     ],
     day_daytime => [
@@ -1763,6 +1887,7 @@ our (%init,
          ],
          [ {}, { hours => 0 } ],
          [ '_weekday', '_daytime_in_the_variant' ],
+         {},
        ],
        [
          { 0 => $RE{weekday}, 1 => $RE{number}, 2 => 'in', 3 => 'the', 4 => 'afternoon' },
@@ -1776,6 +1901,7 @@ our (%init,
          ],
          [ {}, { hours => 12 } ],
          [ '_weekday', '_daytime_in_the_variant' ],
+         {},
        ],
        [
          { 0 => $RE{weekday}, 1 => $RE{number}, 2 => 'in', 3 => 'the', 4 => 'evening' },
@@ -1789,6 +1915,7 @@ our (%init,
          ],
          [ {}, { hours => 12 } ],
          [ '_weekday', '_daytime_in_the_variant' ],
+         {},
        ],
     ],
     variant_weekday_at_time => [
@@ -1806,6 +1933,7 @@ our (%init,
          ],
          [ {}, {} ],
          [ '_count_day_variant_week', '_time' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => $RE{weekday}, 2 => 'at', 3 => $RE{time} },
@@ -1820,6 +1948,7 @@ our (%init,
          ],
          [ {}, {} ],
          [ '_count_day_variant_week', '_time' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => $RE{weekday}, 2 => 'at', 3 => $RE{time} },
@@ -1834,6 +1963,7 @@ our (%init,
          ],
          [ {}, {} ],
          [ '_count_day_variant_week', '_time' ],
+         { truncate_to => 'minute' },
        ],
     ],
     count_day_variant_week => [
@@ -1850,6 +1980,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{day}, 1 => 'day', 2 => qr/^(this)$/i, 3 => 'week' },
@@ -1863,6 +1994,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{day}, 1 => 'day', 2 => qr/^(last)$/i, 3 => 'week' },
@@ -1876,6 +2008,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
     ],
     count_day_variant_month => [
@@ -1892,6 +2025,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_month' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{day}, 1 => 'day', 2 => qr/^(this)$/i, 3 => 'month' },
@@ -1905,6 +2039,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_month' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{day}, 1 => 'day', 2 => qr/^(last)$/i, 3 => 'month' },
@@ -1918,6 +2053,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_month' ],
+         { truncate_to => 'day' },
        ],
     ],
     weekday_variant_week => [
@@ -1934,6 +2070,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{weekday}, 1 => qr/^(this)$/i, 2 => 'week' },
@@ -1947,6 +2084,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{weekday}, 1 => qr/^(last)$/i, 2 => 'week' },
@@ -1960,6 +2098,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
     ],
     variant_week_weekday => [
@@ -1976,6 +2115,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(this)$/i, 1 => 'week', 2 => $RE{weekday} },
@@ -1989,6 +2129,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => qr/^(last)$/i, 1 => 'week', 2 => $RE{weekday} },
@@ -2002,6 +2143,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_day_variant_week' ],
+         { truncate_to => 'day' },
        ],
     ],
     count_month_variant_year => [
@@ -2018,6 +2160,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_month_variant_year' ],
+         { truncate_to => 'month' },
        ],
        [
          { 0 => $RE{day}, 1 => 'month', 2 => qr/^(this)$/i, 3 => 'year' },
@@ -2031,6 +2174,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_month_variant_year' ],
+         { truncate_to => 'month' },
        ],
        [
          { 0 => $RE{day}, 1 => 'month', 2 => qr/^(last)$/i, 3 => 'year' },
@@ -2044,6 +2188,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_month_variant_year' ],
+         { truncate_to => 'month' },
        ],
     ],
     in_count_unit => [
@@ -2055,6 +2200,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'second' } ],
          [ '_in_count_variant' ],
+         {},
        ],
        [
          { 0 => 'in', 1 => $RE{number}, 2 => qr/^(minutes?)$/i },
@@ -2063,6 +2209,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'minute' } ],
          [ '_in_count_variant' ],
+         {},
        ],
        [
          { 0 => 'in', 1 => $RE{number}, 2 => qr/^(hours?)$/i },
@@ -2071,6 +2218,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'hour' } ],
          [ '_in_count_variant' ],
+         {},
        ],
        [
          { 0 => 'in', 1 => $RE{number}, 2 => qr/^(days?)$/i },
@@ -2079,6 +2227,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'day' } ],
          [ '_in_count_variant' ],
+         {},
        ],
        [
          { 0 => 'in', 1 => $RE{number}, 2 => qr/^(weeks?)$/i },
@@ -2087,6 +2236,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'week' } ],
          [ '_in_count_variant' ],
+         {},
        ],
        [
          { 0 => 'in', 1 => $RE{number}, 2 => qr/^(months?)$/i },
@@ -2095,6 +2245,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'month' } ],
          [ '_in_count_variant' ],
+         {},
        ],
        [
          { 0 => 'in', 1 => $RE{number}, 2 => qr/^(years?)$/i },
@@ -2103,6 +2254,7 @@ our (%init,
          [ [ 1 ] ],
          [ { unit => 'year' } ],
          [ '_in_count_variant' ],
+         {},
        ],
     ],
     count_weekday_variant_month => [
@@ -2121,6 +2273,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_weekday_variant_month' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{day}, 1 => $RE{weekday}, 2 => qr/^(this)$/i, 3 => $RE{month} },
@@ -2136,6 +2289,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_weekday_variant_month' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{day}, 1 => $RE{weekday}, 2 => qr/^(last)$/i, 3 => $RE{month} },
@@ -2151,6 +2305,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_weekday_variant_month' ],
+         { truncate_to => 'day' },
        ],
     ],
     daytime_hours_variant => [
@@ -2168,6 +2323,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_hours_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(before)$/i, 3 => qr/^(tomorrow)$/i },
@@ -2182,6 +2338,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_hours_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(after)$/i, 3 => qr/^(yesterday)$/i },
@@ -2196,6 +2353,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_hours_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(after)$/i, 3 => qr/^(tomorrow)$/i },
@@ -2210,6 +2368,7 @@ our (%init,
          ],
          [ {} ],
          [ '_daytime_hours_variant' ],
+         { truncate_to => 'hour' },
        ],
     ],
     hourtime_before_variant => [
@@ -2226,6 +2385,7 @@ our (%init,
          ],
          [ { hour => 12 } ],
          [ '_hourtime_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(before)$/i, 3 => 'midnight' },
@@ -2239,6 +2399,7 @@ our (%init,
          ],
          [ { hour => 0 } ],
          [ '_hourtime_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(after)$/i, 3 => 'noon' },
@@ -2252,6 +2413,7 @@ our (%init,
          ],
          [ { hour => 12 } ],
          [ '_hourtime_variant' ],
+         { truncate_to => 'hour' },
        ],
        [
          { 0 => $RE{number}, 1 => qr/^(hours?)$/i, 2 => qr/^(after)$/i, 3 => 'midnight' },
@@ -2265,6 +2427,7 @@ our (%init,
          ],
          [ { hour => 0 } ],
          [ '_hourtime_variant' ],
+         { truncate_to => 'hour' },
        ],
     ],
     day_at => [
@@ -2281,6 +2444,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_time' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(today)$/i, 1 => 'at', 2 => $RE{time_am} },
@@ -2294,6 +2458,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_time' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => 'at', 2 => $RE{time_am} },
@@ -2307,6 +2472,7 @@ our (%init,
          ],
          [ { unit => 'day' }, {} ],
          [ '_unit_variant', '_time' ],
+         { truncate_to => 'minute' },
        ],
     ],
     weekday_at_time => [
@@ -2323,6 +2489,7 @@ our (%init,
          ],
          [ {}, {} ],
          [ '_weekday', '_time' ],
+         { truncate_to => 'minute' },
        ],
     ],
     day_at_pm => [
@@ -2339,6 +2506,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hours => 12 } ],
          [ '_unit_variant', '_at' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(today)$/i, 1 => 'at', 2 => $RE{time_pm} },
@@ -2352,6 +2520,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hours => 12 } ],
          [ '_unit_variant', '_at' ],
+         { truncate_to => 'minute' },
        ],
        [
          { 0 => qr/^(tomorrow)$/i, 1 => 'at', 2 => $RE{time_pm} },
@@ -2365,6 +2534,7 @@ our (%init,
          ],
          [ { unit => 'day' }, { hours => 12 } ],
          [ '_unit_variant', '_at' ],
+         { truncate_to => 'minute' },
        ],
     ],
     weekday_at_time_pm => [
@@ -2381,6 +2551,7 @@ our (%init,
          ],
          [ {}, { hours => 12 } ],
          [ '_weekday', '_at' ],
+         { truncate_to => 'minute' },
        ],
     ],
     day_month_year => [
@@ -2398,6 +2569,7 @@ our (%init,
          ],
          [ {} ],
          [ '_day_month_year' ],
+         { truncate_to => 'day' },
        ],
        [
          { 0 => $RE{month}, 1 => $RE{monthday}, 2 => $RE{year} },
@@ -2412,6 +2584,7 @@ our (%init,
          ],
          [ {} ],
          [ '_day_month_year' ],
+         { truncate_to => 'day' },
        ],
     ],
     count_weekday_in_month => [
@@ -2430,6 +2603,7 @@ our (%init,
          ],
          [ {} ],
          [ '_count_weekday_variant_month' ],
+         { truncate_to => 'day' },
        ],
     ],
     count_weekday_from_now => [
@@ -2446,8 +2620,26 @@ our (%init,
          ],
          [ {} ],
          [ '_count_weekday_from_now' ],
+         { truncate_to => 'day' },
        ],
-    ]
+    ],
+    final_weekday_in_month => [
+       [ 'SCALAR', 'REGEXP', 'SCALAR', 'REGEXP' ],
+       [
+         { 0 => 'final', 1 => $RE{weekday}, 2 => 'in', 3 => $RE{month} },
+         [],
+         [],
+         [
+           [
+             { 1 => [ $flag{weekday_name}, $flag{weekday_num} ] },
+             { 3 => [ $flag{month_name}, $flag{month_num} ] },
+           ],
+         ],
+         [ {} ],
+         [ '_final_weekday_in_month' ],
+         { truncate_to => 'day' },
+       ],
+    ],
 );
 
 1;
@@ -2650,6 +2842,7 @@ that the parser does not distinguish between lower/upper case):
  6 mondays from now
  fri 3 months ago at 5am
  wednesday 1 month ago at 8pm
+ final thursday in april
 
 =head2 Timespans
 
